@@ -23,28 +23,27 @@ import threading
 import types
 import uuid
 
-import netaddr
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import provider_net
 from neutron_lib.api.definitions import segment as segment_def
-from neutron_lib.api.definitions import stateful_security_group
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
 from neutron_lib import constants as const
 from neutron_lib import context as n_context
+from neutron_lib.db import api as db_api
 from neutron_lib import exceptions as n_exc
 from neutron_lib.exceptions import availability_zone as az_exc
 from neutron_lib.placement import utils as place_utils
 from neutron_lib.plugins import directory
 from neutron_lib.plugins.ml2 import api
 from neutron_lib.utils import helpers
-from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_db import exception as os_db_exc
 from oslo_log import log
 from oslo_service import service as oslo_service
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 from ovsdbapp.backend.ovs_idl import idlutils
 
 from neutron._i18n import _
@@ -54,6 +53,8 @@ from neutron.common.ovn import constants as ovn_const
 from neutron.common.ovn import exceptions as ovn_exceptions
 from neutron.common.ovn import extensions as ovn_extensions
 from neutron.common.ovn import utils as ovn_utils
+from neutron.common import utils as n_utils
+from neutron.common import wsgi_utils
 from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 from neutron.db import ovn_hash_ring_db
 from neutron.db import ovn_revision_numbers_db
@@ -124,7 +125,7 @@ class OVNMechanismDriver(api.MechanismDriver):
         self._maintenance_thread = None
         self._hash_ring_thread = None
         self._hash_ring_probe_event = multiprocessing.Event()
-        self.node_uuid = None
+        self._node_uuid = None
         self.hash_ring_group = ovn_const.HASH_RING_ML2_GROUP
         self.sg_enabled = ovn_acl.is_sg_enabled()
         ovn_conf.register_opts()
@@ -144,6 +145,7 @@ class OVNMechanismDriver(api.MechanismDriver):
         self.qos_driver = qos_driver.OVNQosDriver.create(self)
         self.trunk_driver = trunk_driver.OVNTrunkDriver.create(self)
         self.log_driver = log_driver.register(self)
+        self._start_time = None
         self._agent_cache = None
 
     @property
@@ -185,6 +187,46 @@ class OVNMechanismDriver(api.MechanismDriver):
     def sb_ovn(self, val):
         self._sb_ovn = val
 
+    @property
+    def start_time(self):
+        if self._start_time:
+            return self._start_time
+
+        self._start_time = wsgi_utils.get_start_time()
+        if not self._start_time:
+            LOG.warning('uWSGI must provide a start time using the '
+                        'configuration parameter "start-time %t" in the '
+                        'configuration file')
+            # NOTE(ralonsoh): this is happening if the uWSGI configuration file
+            # does not have the "start-time %t" parameter or when using the
+            # Neutron API eventlet server, still in use in the grenade
+            # skip-level jobs. This should be removed in the F release.
+            self._start_time = wsgi_utils.get_start_time(current_time=True)
+
+        return self._start_time
+
+    @property
+    def node_uuid(self):
+        if self._node_uuid:
+            return self._node_uuid
+
+        worker_id = wsgi_utils.get_api_worker_id()
+        if worker_id is None:
+            # NOTE(ralonsoh): the hash ring node UUID should be based on the
+            # Neutron API worker ID. Right now only uWSGI mode is supported.
+            # The worker ID is provided via ``uwsgi`` library. If other loader
+            # is used, a random node UUID will be provided.
+            LOG.warning('uWSGI is the only supported loader for the Neutron '
+                        'API; it provides, via ``uwsgi`` library, the worker '
+                        'ID. If other loader is used, a random hash ring node '
+                        'UUID will be provided')
+            self._node_uuid = uuidutils.generate_uuid()
+        else:
+            self._node_uuid = ovn_hash_ring_db.get_node_uuid(
+                self.hash_ring_group, cfg.CONF.host, worker_id)
+
+        return self._node_uuid
+
     def get_supported_vif_types(self):
         vif_types = set()
         for ch in self.sb_ovn.chassis_list().execute(check_error=True):
@@ -207,6 +249,14 @@ class OVNMechanismDriver(api.MechanismDriver):
         return (context.current.get(provider_net.NETWORK_TYPE)
                 in vlan_transparency_network_types)
 
+    def check_vlan_qinq(self, context):
+        """OVN driver vlan QinQ support."""
+        vlan_qinq_network_types = [
+            const.TYPE_VLAN,
+        ]
+        return (context.current.get(provider_net.NETWORK_TYPE)
+                in vlan_qinq_network_types)
+
     def _setup_vif_port_bindings(self):
         self.supported_vnic_types = ovn_const.OVN_SUPPORTED_VNIC_TYPES
         self.vif_details = {
@@ -232,10 +282,7 @@ class OVNMechanismDriver(api.MechanismDriver):
         return portbindings.CONNECTIVITY_L2
 
     def supported_extensions(self, extensions):
-        supported_extensions = set(ovn_extensions.ML2_SUPPORTED_API_EXTENSIONS)
-        if not cfg.CONF.ovn.allow_stateless_action_supported:
-            supported_extensions.discard(stateful_security_group.ALIAS)
-        return set(supported_extensions) & extensions
+        return set(ovn_extensions.ML2_SUPPORTED_API_EXTENSIONS) & extensions
 
     @staticmethod
     def provider_network_attribute_updates_supported():
@@ -258,11 +305,6 @@ class OVNMechanismDriver(api.MechanismDriver):
         registry.subscribe(self.delete_segment_provnet_port,
                            resources.SEGMENT,
                            events.AFTER_DELETE)
-        # TODO(slaweq): use constant from neutron_lib.callbacks.resources once
-        # it will be available and released
-        registry.subscribe(self._validate_allowed_address_pairs,
-                           'allowed_address_pair',
-                           events.BEFORE_CREATE)
 
         # Handle security group/rule or address group notifications
         if self.sg_enabled:
@@ -319,37 +361,48 @@ class OVNMechanismDriver(api.MechanismDriver):
                                 worker.MaintenanceWorker,
                                 service.RpcWorker)
 
-    @lockutils.synchronized('hash_ring_probe_lock', external=True)
     def _setup_hash_ring(self):
         """Setup the hash ring.
 
-        The first worker to acquire the lock is responsible for cleaning
-        the hash ring from previous runs as well as start the probing
-        thread for this host. Subsequently workers just need to register
-        themselves to the hash ring.
+        The first worker to execute this method will remove the hash ring from
+        previous runs as well as start the probing thread for this host.
+        Subsequently workers just need to register themselves to the hash ring.
         """
         # Attempt to remove the node from the ring when the worker stops
         sh = oslo_service.SignalHandler()
         atexit.register(self._remove_node_from_hash_ring)
         sh.add_handler("SIGTERM", self._remove_node_from_hash_ring)
+        self._init_hash_ring(n_context.get_admin_context())
+        self._register_hash_ring_maintenance()
 
-        admin_context = n_context.get_admin_context()
-        if not self._hash_ring_probe_event.is_set():
-            # Clear existing entries
-            ovn_hash_ring_db.remove_nodes_from_host(admin_context,
-                                                    self.hash_ring_group)
-            self.node_uuid = ovn_hash_ring_db.add_node(admin_context,
-                                                       self.hash_ring_group)
-            self._hash_ring_thread = maintenance.MaintenanceThread()
-            self._hash_ring_thread.add_periodics(
-                maintenance.HashRingHealthCheckPeriodics(
-                    self.hash_ring_group))
-            self._hash_ring_thread.start()
-            LOG.info("Hash Ring probing thread has started")
-            self._hash_ring_probe_event.set()
-        else:
-            self.node_uuid = ovn_hash_ring_db.add_node(admin_context,
-                                                       self.hash_ring_group)
+    def _register_hash_ring_maintenance(self):
+        """Maintenance method for the node OVN hash ring register
+
+        The ``self.node_uuid`` value must be set before calling this method.
+        """
+        self._hash_ring_thread = maintenance.MaintenanceThread()
+        self._hash_ring_thread.add_periodics(
+            maintenance.HashRingHealthCheckPeriodics(
+                self.hash_ring_group, self.node_uuid))
+        self._hash_ring_thread.start()
+        LOG.info('Hash Ring probing thread for node %s has started',
+                 self.node_uuid)
+
+    @db_api.retry_if_session_inactive()
+    @db_api.CONTEXT_WRITER
+    def _init_hash_ring(self, context):
+        LOG.debug('Hash Ring setup using WSGI start time %s',
+                  str(n_utils.ts_to_datetime(self.start_time)))
+        created_at = n_utils.ts_to_datetime(self.start_time)
+        ovn_hash_ring_db.remove_nodes_from_host(
+            context, self.hash_ring_group, created_at=created_at)
+        ovn_hash_ring_db.add_node(
+            context, self.hash_ring_group, self.node_uuid,
+            created_at=created_at)
+        newer_nodes = ovn_hash_ring_db.get_nodes(
+            context, self.hash_ring_group, created_at=created_at)
+        LOG.debug('Hash Ring setup, this worker has detected %s OVN hash '
+                  'ring registers in the database', len(newer_nodes))
 
     def post_fork_initialize(self, resource, event, trigger, payload=None):
         # Initialize API/Maintenance workers with OVN IDL connections
@@ -444,21 +497,16 @@ class OVNMechanismDriver(api.MechanismDriver):
     def _delete_security_group(self, resource, event, trigger, payload):
         context = payload.context
         security_group_id = payload.resource_id
-        self._ovn_client.delete_security_group(context,
-                                               security_group_id)
+        self._ovn_client.delete_security_group(
+            context, security_group_id, delete_sg_rules=True)
 
     def _update_security_group(self, resource, event, trigger, payload):
         context = payload.context
         security_group = payload.latest_state
 
         old_state, new_state = payload.states
-        is_allow_stateless_supported = (
-            self._ovn_client.is_allow_stateless_supported()
-        )
-        old_stateful = ovn_acl.is_sg_stateful(
-            old_state, is_allow_stateless_supported)
-        new_stateful = ovn_acl.is_sg_stateful(
-            new_state, is_allow_stateless_supported)
+        old_stateful = ovn_acl.is_sg_stateful(old_state)
+        new_stateful = ovn_acl.is_sg_stateful(new_state)
         if old_stateful != new_stateful:
             for rule in self._plugin.get_security_group_rules(
                     context, {'security_group_id': [security_group['id']]}):
@@ -575,49 +623,6 @@ class OVNMechanismDriver(api.MechanismDriver):
                 )
                 raise n_exc.InvalidInput(error_message=m)
 
-    def _validate_allowed_address_pairs(self, resource, event, trigger,
-                                        payload):
-        context = payload.desired_state['context']
-        allowed_address_pairs = payload.desired_state['allowed_address_pairs']
-        network_id = payload.desired_state['network_id']
-        if not allowed_address_pairs:
-            return
-
-        port_allowed_address_pairs_ip_addresses = [
-            netaddr.IPNetwork(pair['ip_address'])
-            for pair in allowed_address_pairs]
-
-        distributed_ports = self._plugin.get_ports(
-            context.elevated(),
-            filters={'device_owner': [const.DEVICE_OWNER_DISTRIBUTED],
-                     'network_id': [network_id]})
-        if not distributed_ports:
-            return
-
-        def _get_common_ips(ip_addresses, ip_networks):
-            common_ips = set()
-            for ip_address in ip_addresses:
-                if any(ip_address in ip_net for ip_net in ip_networks):
-                    common_ips.add(str(ip_address))
-            return common_ips
-
-        for distributed_port in distributed_ports:
-            distributed_port_ip_addresses = [
-                netaddr.IPAddress(fixed_ip['ip_address']) for fixed_ip in
-                distributed_port.get('fixed_ips', [])]
-
-            common_ips = _get_common_ips(
-                distributed_port_ip_addresses,
-                port_allowed_address_pairs_ip_addresses)
-
-            if common_ips:
-                err_msg = (
-                    _("IP addresses '%s' already used by the '%s' port(s) in "
-                      "the same network" % (";".join(common_ips),
-                                            const.DEVICE_OWNER_DISTRIBUTED))
-                )
-                raise n_exc.InvalidInput(error_message=err_msg)
-
     def create_segment_provnet_port(self, resource, event, trigger,
                                     payload=None):
         segment = payload.latest_state
@@ -959,11 +964,11 @@ class OVNMechanismDriver(api.MechanismDriver):
         # the port status from DOWN to UP in order to generate 'fake'
         # vif-interface-plugged event. This workaround is needed to
         # perform live-migration with live_migration_wait_for_vif_plug=True.
-        if ((port['status'] == const.PORT_STATUS_DOWN and
-             ovn_const.MIGRATING_ATTR in port[portbindings.PROFILE].keys() and
-             port[portbindings.VIF_TYPE] in (
+        if (port['status'] == const.PORT_STATUS_DOWN and
+            ovn_const.MIGRATING_ATTR in port[portbindings.PROFILE].keys() and
+            port[portbindings.VIF_TYPE] in (
                  portbindings.VIF_TYPE_OVS,
-                 portbindings.VIF_TYPE_VHOST_USER))):
+                 portbindings.VIF_TYPE_VHOST_USER)):
             LOG.info("Setting port %s status from DOWN to UP in order "
                      "to emit vif-interface-plugged event.",
                      port['id'])
@@ -1491,7 +1496,7 @@ class OVNMechanismDriver(api.MechanismDriver):
                 LOG.debug('Chassis %s is reponsible of the resource provider '
                           '%s', ch_name, ch_rp)
                 return True
-            elif len(states) > 1:
+            if len(states) > 1:
                 rps = {state[0]: placement_ext.dict_chassis_config(state[1])
                        for state in states}
                 LOG.error('Several chassis reported the requested resource '
@@ -1524,17 +1529,13 @@ def update_agent(self, context, id, agent, _driver=None):
     # and we can just fall through to raising in the case that admin_state_up
     # is being set to False, otherwise the end-state will be fine
     if not agent.get('admin_state_up', True):
-        pass
-    elif 'description' in agent:
+        raise n_exc.BadRequest(resource='agent',
+                               msg='OVN agent status cannot be updated')
+    if 'description' in agent:
         _driver.sb_ovn.set_chassis_neutron_description(
             chassis_name, agent['description'],
             agent_type).execute(check_error=True)
-        return agent
-    else:
-        # admin_state_up=True w/o description
-        return agent
-    raise n_exc.BadRequest(resource='agent',
-                           msg='OVN agent status cannot be updated')
+    return agent
 
 
 def delete_agent(self, context, id, _driver=None):
