@@ -35,18 +35,13 @@ from neutron.objects.port_forwarding import PortForwarding
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb.extensions import qos \
     as ovn_qos
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import ovn_client
-from neutron.services.logapi.drivers.ovn import driver as log_driver
 from neutron.services.segments import db as segments_db
 
 
 LOG = log.getLogger(__name__)
 
-SYNC_MODE_OFF = 'off'
-SYNC_MODE_LOG = 'log'
-SYNC_MODE_REPAIR = 'repair'
 
-
-class OvnDbSynchronizer(object, metaclass=abc.ABCMeta):
+class OvnDbSynchronizer(metaclass=abc.ABCMeta):
 
     def __init__(self, core_plugin, ovn_api, ovn_driver):
         self.ovn_driver = ovn_driver
@@ -72,7 +67,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
     """Synchronizer class for NB."""
 
     def __init__(self, core_plugin, ovn_api, sb_ovn, mode, ovn_driver):
-        super(OvnNbSynchronizer, self).__init__(
+        super().__init__(
             core_plugin, ovn_api, ovn_driver)
         self.mode = mode
         self.l3_plugin = directory.get_plugin(plugin_constants.L3)
@@ -87,27 +82,15 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             self.segments_plugin = (
                 manager.NeutronManager.load_class_for_provider(
                     'neutron.service_plugins', 'segments')())
-        self.log_plugin = directory.get_plugin(plugin_constants.LOG_API)
-        if not self.log_plugin:
-            self.log_plugin = (
-                manager.NeutronManager.load_class_for_provider(
-                    'neutron.service_plugins', 'log')())
-            directory.add_plugin(plugin_constants.LOG_API, self.log_plugin)
-        for driver in self.log_plugin.driver_manager.drivers:
-            if driver.name == "ovn":
-                self.ovn_log_driver = driver
-        if not hasattr(self, 'ovn_log_driver'):
-            self.ovn_log_driver = log_driver.OVNDriver()
-            self.log_plugin.driver_manager.register_driver(self.ovn_log_driver)
 
     def stop(self):
         if utils.is_ovn_l3(self.l3_plugin):
             self.l3_plugin._nb_ovn.ovsdb_connection.stop()
             self.l3_plugin._sb_ovn.ovsdb_connection.stop()
-        super(OvnNbSynchronizer, self).stop()
+        super().stop()
 
     def do_sync(self):
-        if self.mode == SYNC_MODE_OFF:
+        if self.mode == ovn_const.OVN_DB_SYNC_MODE_OFF:
             LOG.debug("Neutron sync mode is off, not checking OVN "
                       "Northbound DB for consistency")
             return
@@ -162,7 +145,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         @var   acl_list_dict: Dictionary of acl-lists based on lport as key
         @return: acl_list-dict
         """
-        lswitch_names = set([])
+        lswitch_names = set()
         for network in self.core_plugin.get_networks(context):
             lswitch_names.add(network['id'])
         acl_dict, ignore1, ignore2 = (
@@ -209,11 +192,12 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             LOG.warning('Number of Port Groups to add: %d, remove: %d',
                         len(add_pgs), len(remove_pgs))
 
-        if self.mode == SYNC_MODE_REPAIR and (add_pgs or remove_pgs):
+        if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR and (
+                add_pgs or remove_pgs):
             if add_pgs:
                 db_ports = self.core_plugin.get_ports(ctx)
-                ovn_ports = set(p.name for p in
-                                self.ovn_api.lsp_list().execute())
+                ovn_ports = {p.name for p in
+                             self.ovn_api.lsp_list().execute()}
             with self.ovn_api.transaction(check_error=True) as txn:
                 pg = ovn_const.OVN_DROP_PORT_GROUP_NAME
                 # Process default drop port group first
@@ -249,9 +233,6 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
 
     def _get_acls_from_port_groups(self):
         ovn_acls = []
-        # Options and label columns are only present for OVN >= 22.03.
-        # Furthermore label is a randint so it cannot be compared with any
-        # expected neutron value. They are added later on the ACL addition.
         acl_columns = (self.ovn_api._tables['ACL'].columns.keys() &
                        set(ovn_const.ACL_EXPECTED_COLUMNS_NBDB))
         acl_columns.discard('external_ids')
@@ -263,16 +244,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                 acl_string['port_group'] = pg.name
                 if id_key in acl.external_ids:
                     acl_string[id_key] = acl.external_ids[id_key]
-                # This properties are present as lists of one item,
-                # converting them to string.
-                if acl_string['name']:
-                    acl_string['name'] = acl_string['name'][0]
-                if acl_string['meter']:
-                    acl_string['meter'] = acl_string['meter'][0]
-                if acl_string['severity']:
-                    acl_string['severity'] = acl_string['severity'][0]
                 ovn_acls.append(acl_string)
-
         return ovn_acls
 
     def sync_acls(self, ctx):
@@ -285,34 +257,23 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         LOG.debug('OVN-NB Sync ACLs started @ %s', str(datetime.now()))
 
         neutron_acls = []
-        # if allow-stateless supported, we have to fetch groups to determine if
-        # stateful is set
-        if self._ovn_client.is_allow_stateless_supported():
-            for sg in self.core_plugin.get_security_groups(ctx):
-                stateful = sg.get("stateful", True)
-                pg_name = utils.ovn_port_group_name(sg['id'])
-                for sgr in self.core_plugin.get_security_group_rules(
-                        ctx, {'security_group_id': sg['id']}):
-                    neutron_acls.append(
-                        acl_utils._add_sg_rule_acl_for_port_group(
-                            pg_name, stateful, sgr)
-                    )
-        else:
-            # TODO(ihrachys) remove when min OVN version >= 21.06
-            for sgr in self.core_plugin.get_security_group_rules(ctx):
-                pg_name = utils.ovn_port_group_name(sgr['security_group_id'])
-                neutron_acls.append(acl_utils._add_sg_rule_acl_for_port_group(
-                    pg_name, True, sgr))
+        # we have to fetch groups to determine if stateful is set
+        for sg in self.core_plugin.get_security_groups(ctx):
+            stateful = sg.get("stateful", True)
+            pg_name = utils.ovn_port_group_name(sg['id'])
+            for sgr in self.core_plugin.get_security_group_rules(
+                    ctx, {'security_group_id': sg['id']}):
+                neutron_acls.append(
+                    acl_utils._add_sg_rule_acl_for_port_group(
+                        pg_name, stateful, sgr)
+                )
+
         # Sort the acls in the Neutron database according to the security
         # group rule ID for easy comparison in the future.
         neutron_acls.sort(key=lambda x: x[ovn_const.OVN_SG_RULE_EXT_ID_KEY])
         neutron_default_acls = acl_utils.add_acls_for_drop_port_group(
             ovn_const.OVN_DROP_PORT_GROUP_NAME)
 
-        # Add logging options
-        self.ovn_log_driver.add_logging_options_to_acls(neutron_acls, ctx)
-        self.ovn_log_driver.add_logging_options_to_acls(neutron_default_acls,
-                                                        ctx)
         ovn_acls = self._get_acls_from_port_groups()
         # Sort the acls in the ovn database according to the security
         # group rule id for easy comparison in the future.
@@ -343,24 +304,14 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                 o_index += 1
             elif n_id == o_id:
                 if any(item not in na.items() for item in oa.items()):
-                    for item in oa.items():
-                        if item not in na.items():
-                            LOG.warning('Property %(item)s from OVN ACL not '
-                                        'found in Neutron ACL: %(n_acl)s',
-                                        {'item': item,
-                                         'n_acl': na})
                     add_acls.append(na)
                     remove_acls.append(oa)
                 n_index += 1
                 o_index += 1
             elif n_id > o_id:
-                LOG.warning('ACL should not be present in OVN, removing'
-                            '%(acl)s', {'acl': oa})
                 remove_acls.append(oa)
                 o_index += 1
             else:
-                LOG.warning('ACL should be present in OVN but is not, adding:'
-                            '%(acl)s', {'acl': na})
                 add_acls.append(na)
                 n_index += 1
 
@@ -397,25 +348,9 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                         {'add': num_acls_to_add,
                          'remove': num_acls_to_remove})
 
-        if (self.mode == SYNC_MODE_REPAIR and
+        if (self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR and
                 (num_acls_to_add or num_acls_to_remove)):
             one_time_pg_resync = True
-            with self.ovn_api.transaction(check_error=True) as txn:
-                for aclr in ovn_acls:
-                    LOG.warning('ACLs found in OVN NB DB but not in '
-                                'Neutron for port group %s',
-                                aclr['port_group'])
-                    txn.add(self.ovn_api.pg_acl_del(aclr['port_group'],
-                                                    aclr['direction'],
-                                                    aclr['priority'],
-                                                    aclr['match']))
-                for aclr in ovn_acls_from_ls:
-                    # Remove all the ACLs from any Logical Switch if they have
-                    # any. Elements are (lswitch_name, list_of_acls).
-                    if len(aclr[1]) > 0:
-                        LOG.warning('Removing ACLs from OVN from Logical '
-                                    'Switch %s', aclr[0])
-                        txn.add(self.ovn_api.acl_del(aclr[0]))
             while True:
                 try:
                     with self.ovn_api.transaction(check_error=True) as txn:
@@ -423,18 +358,8 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                             LOG.warning('ACL found in Neutron but not in '
                                         'OVN NB DB for port group %s',
                                         acla['port_group'])
-                            acl = txn.add(self.ovn_api.pg_acl_add(**acla,
-                                                               may_exist=True))
-                            # We need to do this now since label should be
-                            # random and not 0. We can use options as a way
-                            # to see if label is supported or not.
-                            if acla.get('log'):
-                                self.ovn_log_driver.add_label_related(acla,
-                                                                      ctx)
-                                txn.add(self.ovn_api.db_set('ACL', acl,
-                                    label=acla['label'],
-                                    options=acla['options']))
-
+                            txn.add(self.ovn_api.pg_acl_add(
+                                **acla, may_exist=True))
                 except idlutils.RowNotFound as row_err:
                     if row_err.msg.startswith("Cannot find Port_Group"):
                         if one_time_pg_resync:
@@ -452,6 +377,23 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                         raise
                 break
 
+            with self.ovn_api.transaction(check_error=True) as txn:
+                for aclr in ovn_acls:
+                    LOG.warning('ACLs found in OVN NB DB but not in '
+                                'Neutron for port group %s',
+                                aclr['port_group'])
+                    txn.add(self.ovn_api.pg_acl_del(aclr['port_group'],
+                                                    aclr['direction'],
+                                                    aclr['priority'],
+                                                    aclr['match']))
+                for aclr in ovn_acls_from_ls:
+                    # Remove all the ACLs from any Logical Switch if they have
+                    # any. Elements are (lswitch_name, list_of_acls).
+                    if len(aclr[1]) > 0:
+                        LOG.warning('Removing ACLs from OVN from Logical '
+                                    'Switch %s', aclr[0])
+                        txn.add(self.ovn_api.acl_del(aclr[0]))
+
         LOG.debug('OVN-NB Sync ACLs completed @ %s', str(datetime.now()))
 
     def _calculate_routes_differences(self, ovn_routes, db_routes):
@@ -742,7 +684,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                 continue
             LOG.warning("Router found in Neutron but not in "
                         "OVN NB DB, router id=%s", router['id'])
-            if self.mode == SYNC_MODE_REPAIR:
+            if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                 try:
                     LOG.warning("Creating the router %s in OVN NB DB",
                                 router['id'])
@@ -783,7 +725,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         for rp_id, rrport in db_router_ports.items():
             LOG.warning("Router Port found in Neutron but not in OVN NB "
                         "DB, router port_id=%s", rrport['id'])
-            if self.mode == SYNC_MODE_REPAIR:
+            if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                 try:
                     LOG.warning("Creating the router port %s in OVN NB DB",
                                 rrport['id'])
@@ -798,7 +740,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             LOG.warning("Router Port port_id=%s needs to be updated in OVN NB "
                         "DB as network(s) have changed",
                         rport['id'])
-            if self.mode == SYNC_MODE_REPAIR:
+            if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                 try:
                     LOG.warning(
                         "Updating networks on router port %s in OVN NB DB",
@@ -812,7 +754,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             for lrouter in del_lrouters_list:
                 LOG.warning("Router found in OVN NB DB but not in "
                             "Neutron, router id=%s", lrouter['name'])
-                if self.mode == SYNC_MODE_REPAIR:
+                if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                     LOG.warning("Deleting the router %s from OVN NB DB",
                                 lrouter['name'])
                     txn.add(self.ovn_api.lr_del(
@@ -821,7 +763,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             for lrport_info in del_lrouter_ports_list:
                 LOG.warning("Router Port found in OVN NB DB but not in "
                             "Neutron, port_id=%s", lrport_info['port'])
-                if self.mode == SYNC_MODE_REPAIR:
+                if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                     LOG.warning("Deleting the port %s from OVN NB DB",
                                 lrport_info['port'])
                     txn.add(self.ovn_api.delete_lrouter_port(
@@ -833,7 +775,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                     LOG.warning("Router %(id)s static routes %(route)s "
                                 "found in Neutron but not in OVN NB DB",
                                 {'id': sroute['id'], 'route': sroute['add']})
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning("Add static routes %s to OVN NB DB",
                                     sroute['add'])
                         for route in sroute['add']:
@@ -851,7 +793,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                     LOG.warning("Router %(id)s static routes %(route)s "
                                 "found in OVN NB DB but not in Neutron",
                                 {'id': sroute['id'], 'route': sroute['del']})
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning("Delete static routes %s from OVN NB DB",
                                     sroute['del'])
                         routes_to_delete = [
@@ -865,7 +807,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                     LOG.warning("Router %(id)s floating IPs %(fip)s "
                                 "found in OVN NB DB but not in Neutron",
                                 {'id': fip['id'], 'fip': fip['del']})
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning(
                             "Delete floating IPs %s from OVN NB DB",
                             fip['del'])
@@ -876,7 +818,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                     LOG.warning("Router %(id)s floating IPs %(fip)s "
                                 "found in Neutron but not in OVN NB DB",
                                 {'id': fip['id'], 'fip': fip['add']})
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning("Add floating IPs %s to OVN NB DB",
                                     fip['add'])
                         for nat in fip['add']:
@@ -889,7 +831,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                                 "IPs %(fip)s found in OVN NB DB but not in "
                                 "Neutron",
                                 {'id': pf['id'], 'fip': pf['del']})
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning(
                             "Delete port forwarding for floating IPs %s from "
                             "OVN NB DB",
@@ -901,7 +843,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                                 "IPs %(fip)s Neutron out of sync or missing "
                                 "in OVN NB DB",
                                 {'id': pf['id'], 'fip': pf['add']})
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning("Add port forwarding for floating IPs %s "
                                     "to OVN NB DB",
                                     pf['add'])
@@ -914,7 +856,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                     LOG.warning("Router %(id)s SNAT %(snat)s "
                                 "found in OVN NB DB but not in Neutron",
                                 {'id': snat['id'], 'snat': snat['del']})
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning("Delete SNATs %s from OVN NB DB",
                                     snat['del'])
                         for nat in snat['del']:
@@ -927,7 +869,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                     LOG.warning("Router %(id)s SNAT %(snat)s "
                                 "found in Neutron but not in OVN NB DB",
                                 {'id': snat['id'], 'snat': snat['add']})
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning("Add SNATs %s to OVN NB DB",
                                     snat['add'])
                         for nat in snat['add']:
@@ -975,7 +917,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         for subnet_id, subnet in db_subnets.items():
             LOG.warning('DHCP options for subnet %s present in '
                         'Neutron but out of sync with OVN NB DB', subnet_id)
-            if self.mode == SYNC_MODE_REPAIR:
+            if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                 # If neutron-server is running we could race and find a
                 # subnet without a cached network, just skip it to avoid
                 # a KeyError below.
@@ -1004,7 +946,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             LOG.warning('Out of sync DHCP options for subnet %s '
                         'found in OVN NB DB which need to be deleted',
                         dhcp_opt['external_ids']['subnet_id'])
-            if self.mode == SYNC_MODE_REPAIR:
+            if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                 LOG.warning('Deleting DHCP options for subnet %s ',
                             dhcp_opt['external_ids']['subnet_id'])
                 txn_commands.append(self.ovn_api.delete_dhcp_options(
@@ -1017,7 +959,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         LOG.debug('OVN-NB Sync DHCP options for Neutron subnets completed @ '
                   '%s', str(datetime.now()))
 
-    def _sync_port_dhcp_options(self, ctx, ports_need_sync_dhcp_opts,
+    def _sync_port_dhcp_options(self, ports_need_sync_dhcp_opts,
                                 ovn_port_dhcpv4_opts, ovn_port_dhcpv6_opts):
         LOG.debug('OVN-NB Sync DHCP options for Neutron ports with extra '
                   'dhcp options assigned started')
@@ -1027,7 +969,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                         constants.IP_VERSION_6: 'dhcpv6_options'}
         ovn_port_dhcp_opts = {constants.IP_VERSION_4: ovn_port_dhcpv4_opts,
                               constants.IP_VERSION_6: ovn_port_dhcpv6_opts}
-        if self.mode == SYNC_MODE_REPAIR:
+        if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
             for port in ports_need_sync_dhcp_opts:
                 LOG.warning('Updating DHCP options for port %s in OVN NB DB',
                             port['id'])
@@ -1067,7 +1009,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                      'subnet_id': dhcp_opt['external_ids']['subnet_id'],
                      'port_id': port_id})
 
-                if self.mode == SYNC_MODE_REPAIR:
+                if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                     LOG.warning('Deleting port DHCPv%d options for '
                                 '(subnet %s, port %s)', ip_v,
                                 dhcp_opt['external_ids']['subnet_id'], port_id)
@@ -1099,7 +1041,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             if not metadata_ports:
                 LOG.warning('Missing metadata port found in Neutron for '
                             'network %s', net['id'])
-                if self.mode == SYNC_MODE_REPAIR:
+                if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                     try:
                         # Create the missing port in both Neutron and OVN.
                         LOG.warning('Creating missing metadata port in '
@@ -1116,7 +1058,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                 for port in metadata_ports[1:]:
                     LOG.warning('Unnecessary DHCP port %s for network %s '
                                 'found in Neutron', port['id'], net['id'])
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning('Deleting unnecessary DHCP port %s for '
                                     'network %s', port['id'], net['id'])
                         self.core_plugin.delete_port(ctx, port['id'])
@@ -1126,14 +1068,14 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                     LOG.warning('Metadata port %s for network %s found in '
                                 'Neutron but not in OVN NB DB',
                                 port['id'], net['id'])
-                    if self.mode == SYNC_MODE_REPAIR:
+                    if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                         LOG.warning('Creating metadata port %s for network '
                                     '%s in OVN NB DB',
                                     port['id'], net['id'])
                         self._create_port_in_ovn(ctx, port)
                     db_ports.pop(port['id'])
 
-            if self.mode == SYNC_MODE_REPAIR:
+            if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                 try:
                     # Make sure that this port has an IP address in all the
                     # subnets
@@ -1205,10 +1147,10 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             else:
                 del_lswitchs_list.append(lswitch)
 
-        for net_id, network in db_networks.items():
+        for network in db_networks.values():
             LOG.warning("Network found in Neutron but not in "
                         "OVN NB DB, network_id=%s", network['id'])
-            if self.mode == SYNC_MODE_REPAIR:
+            if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                 try:
                     LOG.warning('Creating network %s in OVN NB DB',
                                 network['id'])
@@ -1229,18 +1171,18 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         for port_id, port in db_ports.items():
             LOG.warning("Port found in Neutron but not in OVN NB "
                         "DB, port_id=%s", port['id'])
-            if self.mode == SYNC_MODE_REPAIR:
+            if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                 try:
                     LOG.warning('Creating the port %s in OVN NB DB',
                                 port['id'])
                     self._create_port_in_ovn(ctx, port)
                     if port_id in ovn_all_dhcp_options['ports_v4']:
-                        dhcp_disable, lsp_opts = utils.get_lsp_dhcp_opts(
+                        __, lsp_opts = utils.get_lsp_dhcp_opts(
                             port, constants.IP_VERSION_4)
                         if lsp_opts:
                             ovn_all_dhcp_options['ports_v4'].pop(port_id)
                     if port_id in ovn_all_dhcp_options['ports_v6']:
-                        dhcp_disable, lsp_opts = utils.get_lsp_dhcp_opts(
+                        __, lsp_opts = utils.get_lsp_dhcp_opts(
                             port, constants.IP_VERSION_6)
                         if lsp_opts:
                             ovn_all_dhcp_options['ports_v6'].pop(port_id)
@@ -1252,7 +1194,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             for lswitch in del_lswitchs_list:
                 LOG.warning("Network found in OVN NB DB but not in "
                             "Neutron, network_id=%s", lswitch['name'])
-                if self.mode == SYNC_MODE_REPAIR:
+                if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                     LOG.warning('Deleting network %s from OVN NB DB',
                                 lswitch['name'])
                     txn.add(self.ovn_api.ls_del(lswitch['name']))
@@ -1265,12 +1207,12 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                             "network_id=%(net)s segment_id=%(seg)s",
                             {'net': network['id'],
                              'seg': segment['id']})
-                if self.mode == SYNC_MODE_REPAIR:
+                if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                     LOG.warning('Creating provider network port %s in '
                                 'OVN NB DB',
                                 utils.ovn_provnet_port_name(segment['id']))
                     self._ovn_client.create_provnet_port(
-                        network['id'], segment, txn=txn)
+                        network['id'], segment, txn=txn, network=network)
 
             for provnet_port_info in del_provnet_ports_list:
                 network = provnet_port_info['network']
@@ -1281,7 +1223,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                             "port_name=%(lport)s",
                             {'net': network,
                              'seg': lport})
-                if self.mode == SYNC_MODE_REPAIR:
+                if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                     LOG.warning('Deleting provider network port %s from '
                                 'OVN NB DB', lport)
                     txn.add(self.ovn_api.delete_lswitch_port(
@@ -1291,7 +1233,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             for lport_info in del_lports_list:
                 LOG.warning("Port found in OVN NB DB but not in "
                             "Neutron, port_id=%s", lport_info['port'])
-                if self.mode == SYNC_MODE_REPAIR:
+                if self.mode == ovn_const.OVN_DB_SYNC_MODE_REPAIR:
                     LOG.warning('Deleting port %s from OVN NB DB',
                                 lport_info['port'])
                     txn.add(self.ovn_api.delete_lswitch_port(
@@ -1310,14 +1252,14 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                             ovn_all_dhcp_options['ports_v6'].pop(
                                 lport_info['port'])['uuid']))
 
-        self._sync_port_dhcp_options(ctx, ports_need_sync_dhcp_opts,
+        self._sync_port_dhcp_options(ports_need_sync_dhcp_opts,
                                      ovn_all_dhcp_options['ports_v4'],
                                      ovn_all_dhcp_options['ports_v6'])
         LOG.debug('OVN-NB Sync networks, ports and DHCP options completed @ '
                   '%s', str(datetime.now()))
 
     def sync_port_dns_records(self, ctx):
-        if self.mode != SYNC_MODE_REPAIR:
+        if self.mode != ovn_const.OVN_DB_SYNC_MODE_REPAIR:
             return
         LOG.debug('OVN-NB Sync port DNS records started @ %s',
                   str(datetime.now()))
@@ -1393,7 +1335,7 @@ class OvnSbSynchronizer(OvnDbSynchronizer):
     """Synchronizer class for SB."""
 
     def __init__(self, core_plugin, ovn_api, ovn_driver):
-        super(OvnSbSynchronizer, self).__init__(
+        super().__init__(
             core_plugin, ovn_api, ovn_driver)
         self.l3_plugin = directory.get_plugin(plugin_constants.L3)
 
@@ -1411,9 +1353,6 @@ class OvnSbSynchronizer(OvnDbSynchronizer):
         self.sync_hostname_and_physical_networks(ctx)
         if utils.is_ovn_l3(self.l3_plugin):
             self.l3_plugin.schedule_unhosted_gateways()
-        # NOTE(ralonsoh): this could be called using a resource event.
-        self.ovn_driver._ovn_client.placement_extension.\
-            read_initial_chassis_config()
 
         LOG.debug("OVN-Southbound DB sync process completed @ %s",
                   str(datetime.now()))
@@ -1424,7 +1363,7 @@ class OvnSbSynchronizer(OvnDbSynchronizer):
         host_phynets_map = self.ovn_api.get_chassis_hostname_and_physnets()
         current_hosts = set(host_phynets_map)
         previous_hosts = segments_db.get_hosts_mapped_with_segments(
-            ctx, include_agent_types=set(ovn_const.OVN_CONTROLLER_TYPES))
+            ctx, include_agent_types={ovn_const.OVN_CONTROLLER_AGENT})
 
         stale_hosts = previous_hosts - current_hosts
         for host in stale_hosts:
