@@ -16,8 +16,11 @@ from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import network_mtu as mtu_def
 from neutron_lib.api.definitions import provider_net
 from neutron_lib import constants
+from neutron_lib.plugins import constants as plugins_constants
+from neutron_lib.services.qos import constants as qos_const
 from oslo_config import cfg
 from oslo_utils import strutils
+from oslo_utils import uuidutils
 from sqlalchemy.dialects.mysql import dialect as mysql_dialect
 
 from neutron.common.ovn import constants as ovn_const
@@ -33,8 +36,11 @@ class TestOVNClient(testlib_api.MySQLTestCaseMixin,
                     base.TestOVNFunctionalBase,
                     test_l3.L3NatTestCaseMixin):
 
-    def setUp(self, **kwargs):
-        super().setUp(**kwargs)
+    _extension_drivers = ['qos']
+
+    def setUp(self, *args):
+        service_plugins = {plugins_constants.QOS: 'qos'}
+        super().setUp(service_plugins=service_plugins)
         self.assertEqual(mysql_dialect.name, self.db.engine.dialect.name)
         ext_mgr = test_l3.L3TestExtensionManager()
         self.ext_api = test_extensions.setup_extensions_middleware(ext_mgr)
@@ -122,7 +128,7 @@ class TestOVNClient(testlib_api.MySQLTestCaseMixin,
                     self.assertTrue(strutils.bool_from_string(
                         lrp.external_ids[ovn_const.OVN_ROUTER_IS_EXT_GW]))
                     hcg = self.nb_api.lookup('HA_Chassis_Group',
-                                            ovn_utils.ovn_name(router_id))
+                                             ovn_utils.ovn_name(router_id))
                     self.assertIsNotNone(hcg)
 
                     # Remove the external GW port.
@@ -186,95 +192,6 @@ class TestOVNClient(testlib_api.MySQLTestCaseMixin,
     def test_router_reside_chassis_redirect_non_dvr_geneve_net(self):
         self._test_router_reside_chassis_redirect(False, 'geneve')
 
-    def _check_gw_lrp_mtu(self, router_id, mtu):
-        # Find gateway LRP and check the MTU value.
-        lr = self.nb_api.lookup('Logical_Router',
-                                ovn_utils.ovn_name(router_id))
-        for lrp in lr.ports:
-            if strutils.bool_from_string(
-                    lrp.external_ids[
-                        ovn_const.OVN_ROUTER_IS_EXT_GW]):
-                self.assertEqual(mtu, int(lrp.options['gateway_mtu']))
-                return
-
-        self.fail('Gateway Logical_Router_Port not found for '
-                  'router %s' % router_id)
-
-    def test_update_network_lrp_mtu_updated(self):
-        cfg.CONF.set_override('ovn_emit_need_to_frag', True, group='ovn')
-        self.add_fake_chassis('host1', enable_chassis_as_gw=True, azs=[])
-        net_ext_args = {provider_net.NETWORK_TYPE: 'geneve',
-                        external_net.EXTERNAL: True,
-                        mtu_def.MTU: 1300}
-        net_int_args = {provider_net.NETWORK_TYPE: 'geneve',
-                        mtu_def.MTU: 1400}
-        with self.network(
-                'test-ext-net', as_admin=True,
-                arg_list=tuple(net_ext_args.keys()), **net_ext_args) as \
-                net_ext, self.network(
-                'test-int-net', as_admin=True,
-                arg_list=tuple(net_int_args.keys()), **net_int_args) as \
-                net_int:
-            with self.subnet(net_ext, cidr='10.1.0.0/24'), \
-                    self.subnet(net_int, cidr='10.2.0.0/24') as snet_int:
-                ext_gw = {'network_id': net_ext['network']['id']}
-                with self.router(external_gateway_info=ext_gw) as router:
-                    router_id = router['router']['id']
-                    self._router_interface_action(
-                        'add', router_id, snet_int['subnet']['id'],
-                        None)
-
-                    self._check_gw_lrp_mtu(router_id, 1300)
-
-                    # Update external network MTU.
-                    net_ext_args = {'network': {mtu_def.MTU: 1350}}
-                    req = self.new_update_request('networks', net_ext_args,
-                                                  net_ext['network']['id'])
-                    req.get_response(self.api)
-                    self._check_gw_lrp_mtu(router_id, 1350)
-
-    def test_add_new_router_interfaces_lrp_mtu_updated(self):
-        mtu_ext = 1350
-        internal_interfaces = [{'cidr': '10.2.0.0/24', 'mtu': mtu_ext - 10},
-                               {'cidr': '10.3.0.0/24', 'mtu': mtu_ext + 10},
-                               {'cidr': '10.4.0.0/24', 'mtu': mtu_ext - 20}]
-        cfg.CONF.set_override('ovn_emit_need_to_frag', True, group='ovn')
-        self.add_fake_chassis('host1', enable_chassis_as_gw=True, azs=[])
-        net_ext_args = {provider_net.NETWORK_TYPE: 'geneve',
-                        external_net.EXTERNAL: True,
-                        mtu_def.MTU: mtu_ext}
-        # Store the network's MTUs connected to the router.
-        router_attached_net_mtus = {mtu_ext}
-        with self.network(
-                'test-ext-net', as_admin=True,
-                arg_list=tuple(net_ext_args.keys()), **net_ext_args) as \
-                net_ext:
-            ext_gw = {'network_id': net_ext['network']['id']}
-            with self.subnet(net_ext, cidr='10.1.0.0/24'), \
-                    self.router(external_gateway_info=ext_gw) as router:
-                router_id = router['router']['id']
-                for _int in internal_interfaces:
-                    # Attach a new internal interface to the router. If the new
-                    # network MTU is lower than the minimum MTU connected, the
-                    # GW LRP.options.gateway_mtu will be updated.
-                    net_int_args = {provider_net.NETWORK_TYPE: 'geneve',
-                                    mtu_def.MTU: _int['mtu']}
-                    router_attached_net_mtus.add(_int['mtu'])
-                    net_int = self._make_network(
-                        self.fmt, name='nettest', admin_state_up=True,
-                        **net_int_args)
-                    snet_int = self._make_subnet(
-                        self.fmt, net_int, constants.ATTR_NOT_SPECIFIED,
-                        _int['cidr'])
-                    self._router_interface_action(
-                        'add', router_id, snet_int['subnet']['id'],
-                        None)
-
-                    # The GW LRP "gateway_mtu" value should be the minimum
-                    # MTU connected to the router.
-                    self._check_gw_lrp_mtu(router_id,
-                                           min(router_attached_net_mtus))
-
     def test_process_address_group(self):
         def _find_address_set_for_ag():
             as_v4 = self.nb_api.lookup(
@@ -315,3 +232,208 @@ class TestOVNClient(testlib_api.MySQLTestCaseMixin,
         # Delete the address group
         ovn_client.delete_address_group(self.context, ag['id'])
         self.assertEqual((None, None), _find_address_set_for_ag())
+
+    def _check_gw_lrp_mtu(self, router_id, mtu):
+        # Find gateway LRP and check the MTU value.
+        lr = self.nb_api.lookup('Logical_Router',
+                                ovn_utils.ovn_name(router_id))
+        for lrp in lr.ports:
+            if strutils.bool_from_string(
+                    lrp.external_ids[
+                        ovn_const.OVN_ROUTER_IS_EXT_GW]):
+                self.assertEqual(mtu, int(lrp.options['gateway_mtu']))
+                return
+
+        self.fail('Gateway Logical_Router_Port not found for '
+                  'router %s' % router_id)
+
+    def test_update_network_lrp_mtu_updated(self):
+        self.add_fake_chassis('host1', enable_chassis_as_gw=True, azs=[])
+        net_ext_args = {provider_net.NETWORK_TYPE: 'geneve',
+                        external_net.EXTERNAL: True,
+                        mtu_def.MTU: 1300}
+        net_int_args = {provider_net.NETWORK_TYPE: 'geneve',
+                        mtu_def.MTU: 1400}
+        with self.network(
+                'test-ext-net', as_admin=True,
+                arg_list=tuple(net_ext_args.keys()), **net_ext_args) as \
+                net_ext, self.network(
+                'test-int-net', as_admin=True,
+                arg_list=tuple(net_int_args.keys()), **net_int_args) as \
+                net_int:
+            with self.subnet(net_ext, cidr='10.1.0.0/24'), \
+                    self.subnet(net_int, cidr='10.2.0.0/24') as snet_int:
+                ext_gw = {'network_id': net_ext['network']['id']}
+                with self.router(external_gateway_info=ext_gw) as router:
+                    router_id = router['router']['id']
+                    self._router_interface_action(
+                        'add', router_id, snet_int['subnet']['id'],
+                        None)
+
+                    self._check_gw_lrp_mtu(router_id, 1300)
+
+                    # Update external network MTU.
+                    net_ext_args = {'network': {mtu_def.MTU: 1350}}
+                    req = self.new_update_request('networks', net_ext_args,
+                                                  net_ext['network']['id'])
+                    req.get_response(self.api)
+                    self._check_gw_lrp_mtu(router_id, 1350)
+
+    def test_add_new_router_interfaces_lrp_mtu_updated(self):
+        mtu_ext = 1350
+        internal_interfaces = [{'cidr': '10.2.0.0/24', 'mtu': mtu_ext - 10},
+                               {'cidr': '10.3.0.0/24', 'mtu': mtu_ext + 10},
+                               {'cidr': '10.4.0.0/24', 'mtu': mtu_ext - 20}]
+        self.add_fake_chassis('host1', enable_chassis_as_gw=True, azs=[])
+        net_ext_args = {provider_net.NETWORK_TYPE: 'geneve',
+                        external_net.EXTERNAL: True,
+                        mtu_def.MTU: mtu_ext}
+        # Store the network's MTUs connected to the router.
+        router_attached_net_mtus = {mtu_ext}
+        with self.network(
+                'test-ext-net', as_admin=True,
+                arg_list=tuple(net_ext_args.keys()), **net_ext_args) as \
+                net_ext:
+            ext_gw = {'network_id': net_ext['network']['id']}
+            with self.subnet(net_ext, cidr='10.1.0.0/24'), \
+                    self.router(external_gateway_info=ext_gw) as router:
+                router_id = router['router']['id']
+                for _int in internal_interfaces:
+                    # Attach a new internal interface to the router. If the new
+                    # network MTU is lower than the minimum MTU connected, the
+                    # GW LRP.options.gateway_mtu will be updated.
+                    net_int_args = {provider_net.NETWORK_TYPE: 'geneve',
+                                    mtu_def.MTU: _int['mtu']}
+                    router_attached_net_mtus.add(_int['mtu'])
+                    net_int = self._make_network(
+                        self.fmt, name='nettest', admin_state_up=True,
+                        **net_int_args)
+                    snet_int = self._make_subnet(
+                        self.fmt, net_int, constants.ATTR_NOT_SPECIFIED,
+                        _int['cidr'])
+                    self._router_interface_action(
+                        'add', router_id, snet_int['subnet']['id'],
+                        None)
+
+                    # The GW LRP "gateway_mtu" value should be the minimum
+                    # MTU connected to the router.
+                    self._check_gw_lrp_mtu(router_id,
+                                           min(router_attached_net_mtus))
+
+    def test_create_router_port_multiple_routers(self):
+        # The goal of this test is to check that the GW LRPs are updated when
+        # the same network is the external GW for several routers.
+        net_ext_args = {provider_net.NETWORK_TYPE: 'geneve',
+                        external_net.EXTERNAL: True,
+                        mtu_def.MTU: 1400}
+        net_ext = self._make_network(self.fmt, 'test-ext-net', True,
+                                     as_admin=True,
+                                     arg_list=tuple(net_ext_args.keys()),
+                                     **net_ext_args)
+        ext_gw = {'network_id': net_ext['network']['id']}
+        self._make_subnet(self.fmt, net_ext,
+                          gateway=constants.ATTR_NOT_SPECIFIED,
+                          cidr='10.100.0.0/24')
+        nets_int = []
+        routers = []
+        subnets = []
+        for idx in range(3):
+            cidr = f'10.{idx}.0.0/24'
+            net_int_args = {provider_net.NETWORK_TYPE: 'geneve',
+                            mtu_def.MTU: 1300 + idx}
+            nets_int.append(self._make_network(
+                self.fmt, 'test-int-net', True, as_admin=True,
+                arg_list=tuple(net_ext_args.keys()), **net_int_args))
+            subnets.append(self._make_subnet(
+                self.fmt, nets_int[-1],
+                gateway=constants.ATTR_NOT_SPECIFIED, cidr=cidr))
+            routers.append(self._make_router(
+                self.fmt, external_gateway_info=ext_gw))
+
+        for router in routers:
+            lr_name = ovn_utils.ovn_name(router['router']['id'])
+            lrp = self.nb_api.lrp_list(lr_name).execute(check_errors=True)[0]
+            self.assertEqual(1400, int(lrp.options['gateway_mtu']))
+
+        # Add to every router a new internal subnet. That must update the
+        # GW LRP MTU.
+        for idx, router in enumerate(routers):
+            lr_name = ovn_utils.ovn_name(router['router']['id'])
+            subnet = subnets[idx]
+            self._router_interface_action(
+                'add', router['router']['id'], subnet['subnet']['id'],
+                None)
+            lrps = self.nb_api.lrp_list(lr_name).execute(check_errors=True)
+            for lrp in lrps:
+                if strutils.bool_from_string(
+                        lrp.external_ids[ovn_const.OVN_ROUTER_IS_EXT_GW]):
+                    # New MTU=1300+idx (old MTU=1400)
+                    self.assertEqual(1300 + idx,
+                                     int(lrp.options['gateway_mtu']))
+
+        # Remove the internal subnet. The GW LRP should restore the GW network
+        # MTU=1400.
+        for idx, router in enumerate(routers):
+            lr_name = ovn_utils.ovn_name(router['router']['id'])
+            subnet = subnets[idx]
+            self._router_interface_action(
+                'remove', router['router']['id'], subnet['subnet']['id'],
+                None)
+            lrps = self.nb_api.lrp_list(lr_name).execute(check_errors=True)
+            for lrp in lrps:
+                if strutils.bool_from_string(
+                        lrp.external_ids[ovn_const.OVN_ROUTER_IS_EXT_GW]):
+                    # GW network MTU=1400
+                    self.assertEqual(1400, int(lrp.options['gateway_mtu']))
+
+    def test_update_port_with_qos(self):
+        def _check_bw(port_id, max_kbps=None, max_burst_kbps=None):
+            lsp = self.nb_api.lookup('Logical_Switch_Port', port_id)
+            if max_kbps:
+                self.assertEqual(
+                    '{}'.format(max_kbps * 1000),
+                    lsp.options[ovn_const.LSP_OPTIONS_QOS_MAX_RATE])
+            else:
+                self.assertNotIn(ovn_const.LSP_OPTIONS_QOS_MAX_RATE,
+                                 lsp.options)
+            if max_burst_kbps:
+                self.assertEqual(
+                    '{}'.format(max_burst_kbps * 1000),
+                    lsp.options[ovn_const.LSP_OPTIONS_QOS_BURST])
+            else:
+                self.assertNotIn(ovn_const.LSP_OPTIONS_QOS_BURST,
+                                 lsp.options)
+
+        res = self._create_qos_policy(self.fmt, is_admin=True)
+        qos = self.deserialize(self.fmt, res)['policy']
+        max_kbps, max_burst_kbps = 1000, 800
+        self._create_qos_rule(self.fmt, qos['id'],
+                              qos_const.RULE_TYPE_BANDWIDTH_LIMIT,
+                              max_kbps=max_kbps, max_burst_kbps=max_burst_kbps,
+                              is_admin=True)
+        net_args = {provider_net.NETWORK_TYPE: 'flat',
+                    provider_net.PHYSICAL_NETWORK: 'datacentre'}
+        with self.network(uuidutils.generate_uuid(),
+                          arg_list=tuple(net_args.keys()), as_admin=True,
+                          **net_args) as net:
+            with self.subnet(net) as subnet:
+                with self.port(subnet) as port:
+                    port_data = port['port']
+                    # Check no QoS options.
+                    _check_bw(port_data['id'])
+
+                    # Add QoS policy.
+                    req = self.new_update_request(
+                        'ports',
+                        {'port': {'qos_policy_id': qos['id']}},
+                        port_data['id'])
+                    req.get_response(self.api)
+                    _check_bw(port_data['id'], max_kbps, max_burst_kbps)
+
+                    # Update port.
+                    req = self.new_update_request(
+                        'ports',
+                        {'port': {'name': uuidutils.generate_uuid()}},
+                        port_data['id'])
+                    req.get_response(self.api)
+                    _check_bw(port_data['id'], max_kbps, max_burst_kbps)
